searchNodes=[{"doc":"Generates definitions of various things related to tagged value tuples, like {:ok, value} and {:error, reason}.Examplesdefmodule Tagged.Status use Tagged deftagged ok deftagged error endConstruct and Destructureiex&gt; use Tagged.Status iex&gt; ok(:computer) {:ok, :computer} iex&gt; with error(reason) &lt;- {:ok, :computer}, do: raise reason {:ok, :computer}Type definitions_iex&gt; use Tagged.Status _iex&gt; t Tagged.Status.error @type error() :: {:error, term()} Tagged value tuple, containing term().","ref":"Tagged.html","title":"Tagged","type":"module"},{"doc":"Generates a macro that definies all things related to a tagged value tuple, {atom(), term()}. By default the macro has the same name as the tag, and all the things are generated.Keywordsas: nameOverride default macro name. See Tagged.Constructortype: falseOverride type definition. See Tagged.Typedef","ref":"Tagged.html#deftagged/2","title":"Tagged.deftagged/2","type":"macro"},{"doc":"Generates macros for constructing, and destructuring tagged value tuples. By default, the macro name is the same as the tag, but can be overriden with the as: name keyword argument.This module is always executed.ExamplesDefine constructors with the same name as the tagdefmodule Tagged.Status use Tagged deftagged ok deftagged error end iex&gt; use Tagged.Status iex&gt; ok(:computer) {:ok, :computer} iex&gt; with ok(it) &lt;- Keyword.fetch([a: &quot;bacon&quot;], :a), do: &quot;Chunky \#{it}!&quot; &quot;Chunky bacon!&quot;Override constructor namedefmodule Tagged.Outcome use Tagged deftagged ok, as: success deftagged error, as: failure end iex&gt; use Tagged.Outcome iex&gt; failure(:is_human) {:error, :is_human} iex&gt; with success(it) &lt;- {:ok, &quot;Computer&quot;}, do: &quot;OK, \#{it}!&quot; &quot;OK, Computer!&quot;","ref":"Tagged.Constructor.html","title":"Tagged.Constructor","type":"module"},{"doc":"Reasoning in terms of the outcome of an action.iex&gt; use Tagged.Outcome iex&gt; failure(:is_human) {:error, :is_human} iex&gt; with success(it) &lt;- {:ok, &quot;Computer&quot;}, do: &quot;OK, \#{it}!&quot; &quot;OK, Computer!&quot;","ref":"Tagged.Outcome.html","title":"Tagged.Outcome","type":"module"},{"doc":"Constructor for error tagged value tuples. Can also be used to destructure tuples.iex&gt; use Elixir.Tagged.Constructor iex&gt; with failure(val) &lt;- {:error, :match}, do: val :match iex&gt; with failure(_) &lt;- {:not_error, :match}, do: true {:not_error, :match}","ref":"Tagged.Outcome.html#failure/1","title":"Tagged.Outcome.failure/1","type":"macro"},{"doc":"Constructor for ok tagged value tuples. Can also be used to destructure tuples.iex&gt; use Elixir.Tagged.Constructor iex&gt; with success(val) &lt;- {:ok, :match}, do: val :match iex&gt; with success(_) &lt;- {:not_ok, :match}, do: true {:not_ok, :match}","ref":"Tagged.Outcome.html#success/1","title":"Tagged.Outcome.success/1","type":"macro"},{"doc":"Tagged value tuple, containing term().","ref":"Tagged.Outcome.html#t:failure/0","title":"Tagged.Outcome.failure/0","type":"type"},{"doc":"Tagged value tuple, containing term().","ref":"Tagged.Outcome.html#t:success/0","title":"Tagged.Outcome.success/0","type":"type"},{"doc":"Resoning in terms of the status of a result.iex&gt; use Tagged.Status iex&gt; ok(:computer) {:ok, :computer} iex&gt; with ok(it) &lt;- Keyword.fetch([a: &quot;bacon&quot;], :a), do: &quot;Chunky \#{it}!&quot; &quot;Chunky bacon!&quot;","ref":"Tagged.Status.html","title":"Tagged.Status","type":"module"},{"doc":"Constructor for error tagged value tuples. Can also be used to destructure tuples.iex&gt; use Elixir.Tagged.Constructor iex&gt; with error(val) &lt;- {:error, :match}, do: val :match iex&gt; with error(_) &lt;- {:not_error, :match}, do: true {:not_error, :match}","ref":"Tagged.Status.html#error/1","title":"Tagged.Status.error/1","type":"macro"},{"doc":"Constructor for ok tagged value tuples. Can also be used to destructure tuples.iex&gt; use Elixir.Tagged.Constructor iex&gt; with ok(val) &lt;- {:ok, :match}, do: val :match iex&gt; with ok(_) &lt;- {:not_ok, :match}, do: true {:not_ok, :match}","ref":"Tagged.Status.html#ok/1","title":"Tagged.Status.ok/1","type":"macro"},{"doc":"Tagged value tuple, containing term().","ref":"Tagged.Status.html#t:error/0","title":"Tagged.Status.error/0","type":"type"},{"doc":"Tagged value tuple, containing term().","ref":"Tagged.Status.html#t:ok/0","title":"Tagged.Status.ok/0","type":"type"},{"doc":"Generates type definitions for tagged value tuples.This module is executed by default, but can be disabled with type: false as keyword argument for either defmacro or use Tagged.ExamplesDisable type declaration for all tagged value tuple definitionsdefmodule NoTypes do use Tagged, type: false deftagged foo end _iex&gt; use NoTypes _iex&gt; t NoTypes.foo No type information for NoTypes.foo was found or NoTypes.foo is privateOverride type declaration for a single tagged value tuple definitiondefmodule SomeTypes do use Tagged deftagged foo, type: false deftagged bar end _iex&gt; use Types _iex&gt; t NoTypes.foo No type information for NoTypes.foo was found or NoTypes.foo is private _iex&gt; t NoTypes.bar @type bar() :: {:bar, term()} Tagged value tuple, containing term().","ref":"Tagged.Typedef.html","title":"Tagged.Typedef","type":"module"}]